@@ -175,7 +175,10 @@ def legend(ax=None, min_label_distance="auto", alpha: float = 1.0):
     xlim0, xlim1 = ax.get_xlim()
     for label, t, color in zip(labels, targets, colors):
         plt.text(
-            xlim1 + (xlim1 - xlim0) / 100,
+            # Leave the labels some space to breathe. If they are too close to the
+            # lines, they can get visually merged.
+            # <https://twitter.com/EdwardTufte/status/1416035189843714050>
+            xlim1 + (xlim1 - xlim0) / 100 * 3,
             t,
             label,
             verticalalignment="center",
@@ -198,7 +201,8 @@ def ylabel(string):
     ticks = ticks[(-tol < ticks) & (ticks < 1.0 + tol)]
 
     # Get the padding in axes coordinates. The below logic isn't quite correct, so keep
-    # an eye on <https://stackoverflow.com/q/67872207/353337>.
+    # an eye on <https://stackoverflow.com/q/67872207/353337> and
+    # <https://discourse.matplotlib.org/t/get-ytick-label-distance-in-axis-coordinates/22210>.
     yticks = ax.yaxis.get_major_ticks()
     if len(yticks) > 0:
         pad_pt = yticks[-1].get_pad()
